# Changelog

## 1.2.0 (2025-08-06)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/victorgabrieldeon/fv-api/compare/v1.1.0...v1.2.0)

### Features

* clean up environment call outs ([3b9938b](https://github.com/victorgabrieldeon/fv-api/commit/3b9938b494080b008de7d4ebed8d8834a594c383))
* **client:** support file upload requests ([534ad6b](https://github.com/victorgabrieldeon/fv-api/commit/534ad6b682c03d081361381be63ec92409fa143d))


### Bug Fixes

* **ci:** correct conditional ([4311ef4](https://github.com/victorgabrieldeon/fv-api/commit/4311ef485966b898385fbc579e1aa7006ab79559))
* **client:** don't send Content-Type header on GET requests ([91bc0f9](https://github.com/victorgabrieldeon/fv-api/commit/91bc0f9b24c5a458d1b3996af669fc798fea307c))
* **parsing:** correctly handle nested discriminated unions ([fc891c3](https://github.com/victorgabrieldeon/fv-api/commit/fc891c3c7fc8ff1b16268a29e07e638e7b8304d1))
* **parsing:** ignore empty metadata ([c4fbbaf](https://github.com/victorgabrieldeon/fv-api/commit/c4fbbafb36fe31336fd5fa27bb996fc7180e7548))
* **parsing:** parse extra field types ([ab92ecf](https://github.com/victorgabrieldeon/fv-api/commit/ab92ecf4d966c163117270827d5993e19941fab7))


### Chores

* **ci:** change upload type ([2b80a53](https://github.com/victorgabrieldeon/fv-api/commit/2b80a53fe1ef53d6cee6ab5473fe03581334011b))
* **internal:** bump pinned h11 dep ([75d6474](https://github.com/victorgabrieldeon/fv-api/commit/75d64741de5f6448208811b27d25240b6611e413))
* **internal:** codegen related update ([a296282](https://github.com/victorgabrieldeon/fv-api/commit/a29628273740da5dbfaa53f39da5f12a82942fcc))
* **internal:** fix ruff target version ([e719b8d](https://github.com/victorgabrieldeon/fv-api/commit/e719b8d4b6fd189c30fa829d0491b12145cb87ec))
* **package:** mark python 3.13 as supported ([04df3c3](https://github.com/victorgabrieldeon/fv-api/commit/04df3c3e0b79617b7226fd47e16bd006dca74414))
* **project:** add settings file for vscode ([a65421e](https://github.com/victorgabrieldeon/fv-api/commit/a65421ec4bf978a232d23d9a2815569daa35f069))
* **readme:** fix version rendering on pypi ([8ccba1f](https://github.com/victorgabrieldeon/fv-api/commit/8ccba1f68afd5f1fd859201c09f5a21c44249b35))

## 1.1.0 (2025-06-28)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/victorgabrieldeon/fv-api/compare/v1.0.1...v1.1.0)

### Features

* **client:** add support for aiohttp ([3534a3e](https://github.com/victorgabrieldeon/fv-api/commit/3534a3eecbed1108a21f11f798748b280e4210cc))


### Bug Fixes

* **ci:** release-doctor — report correct token name ([f70ee3e](https://github.com/victorgabrieldeon/fv-api/commit/f70ee3ea64a17500b2108224f81adc16af371833))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([89cd780](https://github.com/victorgabrieldeon/fv-api/commit/89cd780492fb7b46aa533b0f46ac132a61726d9f))


### Chores

* **ci:** only run for pushes and fork pull requests ([73594cb](https://github.com/victorgabrieldeon/fv-api/commit/73594cb0dd8113bab6b1e7b69c3013d4f189dbde))
* **readme:** update badges ([0a47345](https://github.com/victorgabrieldeon/fv-api/commit/0a47345d59a7d2890b11b5da490ff334e54dce3f))
* **tests:** skip some failing tests on the latest python versions ([94cd14f](https://github.com/victorgabrieldeon/fv-api/commit/94cd14feb2c7f6b1cc0ee01648837c4355849d0b))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([ba8dd19](https://github.com/victorgabrieldeon/fv-api/commit/ba8dd19ada354aada7ab12e5c03d203c43ef0b3a))

## 1.0.1 (2025-06-17)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/victorgabrieldeon/fv-api/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([96ef2d8](https://github.com/victorgabrieldeon/fv-api/commit/96ef2d83cecf6be5c5baaa8fc8e92ff5f9f12d66))

## 1.0.0 (2025-06-17)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/victorgabrieldeon/fv-api/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([d32a8e0](https://github.com/victorgabrieldeon/fv-api/commit/d32a8e06890e7675ef95f80e8f51bcd4a74a3285))
* update SDK settings ([125f1a7](https://github.com/victorgabrieldeon/fv-api/commit/125f1a7cb1889b650ff268bf5c5fc26484757226))
